(function($){

    "use strict";

    var AMCRMAddons = {

        init: function()
        {
            // Document ready.
            this._bind();
            $( document ).ready( AMCRMAddons._loadPopup() );
        },

        /**
         * Binds events for the Form Builder.
         *
         * @since 1.0.0
         * @access private
         * @method _bind
         */
        _bind: function()
        {
            $( document ).on('click', '.auto-mail-connect-integration', AMCRMAddons._selectIntegration );
            $( document ).on('click', '.robot-addon-connect', AMCRMAddons._saveAPIData );
            $( document ).on('auto-mail-reload-integration-page', AMCRMAddons._reloadIntegrationPage );
        },

        /**
         * Reload Integration Page
         *
         */
         _reloadIntegrationPage: function( event ) {

            event.preventDefault();

            var target_url = Auto_Mail_Data.addons_url;
            window.location.replace(target_url);

        },

        /**
         * Save API Data
         *
         */
         _saveAPIData: function( event ) {

            event.preventDefault();


            var formdata = $('.robot-integration-form').serializeArray();
            var fields = {};
            $(formdata ).each(function(index, obj){
                fields[obj.name] = obj.value;
            });

            $.ajax({
                    url  : Auto_Mail_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_mail_save_api_data',
                        fields_data  : fields,
                        _ajax_nonce  : Auto_Mail_Data._ajax_nonce,
                    },
                    beforeSend: function() {
                        $('.robot-loading-text').text('Loading...');
                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( result ) {
                    console.log(result);
                    if( false === result.success ) {
                        console.log(result);
                        AMCRMAddons._displayNoticeMessage(result.data);
                        $('.robot-error-message-name').css("display", "block");
                        $('.robot-loading-text').text('Connect');
                    } else {
                        $('.robot-loading-text').text('Connect');

                        AMCRMAddons._displayNoticeMessage(result.data);

                        setTimeout(function(){
                         $(document).trigger( 'auto-mail-reload-integration-page' );
                        }, 3000);
                    }


                });


        },

        /**
         * Display Notice Message
         *
         */
         _displayNoticeMessage: function(message) {

            event.preventDefault();

            var html = '<div class="message-box robot-message-box success">' + message + '</div>';
            $(html).appendTo(".auto-mail-wrap").fadeIn('slow').animate({opacity: 1.0}, 2500).fadeOut('slow');;

        },

        /**
         * Load Popup
         *
         */
         _loadPopup: function( ) {

            $('.auto-mail-connect-integration').magnificPopup({
                type:'inline',
                midClick: true, // Allow opening popup on middle mouse click. Always set it to true if you don't provide alternative source in href.
                // Delay in milliseconds before popup is removed
                removalDelay: 300,

                // Class that is added to popup wrapper and background
                // make it unique to apply your CSS animations just to this exact popup
                callbacks: {
                    beforeOpen: function() {
                        this.st.mainClass = this.st.el.attr('data-effect');
                    }
                },
            });

        },

        /**
         * Display Actions
         *
         */
         _selectIntegration: function( event ) {

            event.preventDefault();


            var slug = $(this).data('slug');

            console.log(slug);

            $.ajax({
                    url  : Auto_Mail_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_mail_select_addon',
                        template     : slug,
                        _ajax_nonce  : Auto_Mail_Data._ajax_nonce,
                    },
                    beforeSend: function() {
                        $('#integration-popup').empty();
                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( result ) {
                    console.log(result);
                    if( false === result.success ) {
                        console.log(result);
                    } else {
                        $('#integration-popup').html(result.data);
                    }
                });


        },

    };

    /**
     * Initialize AMCRMAddons
     */
    $(function(){
        AMCRMAddons.init();
    });

})(jQuery);
