<?php
/**
 * Auto_Mail_Addon_Loader Class
 *
 * @since  1.0.0
 * @package Auto Robot
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if ( ! class_exists( 'Auto_Mail_Addon_Loader' ) ) :

    class Auto_Mail_Addon_Loader {

        /**
         * Array Access-able of Registered Addons
         *
         * @since 1.0.0
         * @var array
         */
        private $addons = array();

        /**
         * @since 1.0.0
         * @var self
         */
        private static $instance = null;

        /**
         * Get instance of loader
         *
         * @since 1.0.0
         * @return Auto_Mail_Addon_Loader
         */
        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self();
            }

            return self::$instance;
        }


        /**
         * Auto_Mail_Addon_Loader constructor.
         *
         * @since 1.0.0
         */
        public function __construct() {

            // Initial addons data.
            $addons = array(
                array(
                    'name' => 'ActiveCampaign',
                    'slug' => 'activecampaign',
                    'type' => 'social',
                    'icon_url' => AUTO_MAIL_URL.'/assets/images/addons/activecampaign.png',
                    'is_connected' => false
                ),
                array(
                    'name' => 'Mailchimp',
                    'slug' => 'mailchimp',
                    'type' => 'social',
                    'icon_url' => AUTO_MAIL_URL.'/assets/images/addons/mailchimp.png',
                    'is_connected' => false
                ),
                array(
                    'name' => 'Mailerlite',
                    'slug' => 'mailerlite',
                    'type' => 'social',
                    'icon_url' => AUTO_MAIL_URL.'/assets/images/addons/mailerlite.png',
                    'is_connected' => false
                ),
                array(
                    'name' => 'Mailpoet',
                    'slug' => 'mailpoet',
                    'type' => 'social',
                    'icon_url' => AUTO_MAIL_URL.'/assets/images/addons/mailpoet.png',
                    'is_connected' => false
                ),
                array(
                    'name' => 'Sendgrid',
                    'slug' => 'sendgrid',
                    'type' => 'social',
                    'icon_url' => AUTO_MAIL_URL.'/assets/images/addons/sendgrid.png',
                    'is_connected' => false
                ),
                array(
                    'name' => 'Sendinblue',
                    'slug' => 'sendinblue',
                    'type' => 'social',
                    'icon_url' => AUTO_MAIL_URL.'/assets/images/addons/sendinblue.png',
                    'is_connected' => false
                ),
            );

            $auto_mail_addons = get_option( 'auto_mail_addons', false );

            if ( !$auto_mail_addons || count($auto_mail_addons) !== count($addons) ) {
                update_option( 'auto_mail_addons', $addons );
            }

            $this->addons = get_option( 'auto_mail_addons', false );
        }

        /**
         * Get Addons
         *
         * @since 1.0.0
         **
         * @return array
         */
        public function get_addons( ) {
            return $this->addons;
        }

        /**
         * Save addon data
         *
         * @since 1.0.0
         **
         * @return bool
         */
        public function save_addon_data($data) {

            $addons = $this->addons;

            foreach ( $addons as $key => $addon ) {

                if ( $addon['slug'] == $data['slug'] ) {
                    // Set is_connected true
                    if($data['is_connected']){
                        $data['is_connected'] = false;
                    }else{
                        $data['is_connected'] = true;
                    }
                    $addons[$key] = array_merge($addons[$key], $data);
                }
            }

            update_option( 'auto_mail_addons', $addons );

        }

        /**
         * Connect Mail Service
         *
         * @since 1.0.0
         **
         * @return bool
         */
        public function connect_mail_service($data) {

            $addons = $this->addons;

            foreach ( $addons as $key => $addon ) {

                if ( $addon['slug'] == $data['slug'] ) {
                    // Set mail service connected data
                    $service = $data['slug'].'_list';
                    $addons[$key]['service'][$data['form_id']] = $data[$service];

                    $addons[$key] = array_merge($addons[$key], $data);

                }
            }

            update_option( 'auto_mail_addons', $addons );

        }

        /**
         * Connect Mail Service
         *
         * @since 1.0.0
         **
         * @return bool
         */
        public function subscribe_mail_service($form_id, $email) {

            $addons = $this->addons;

            foreach ( $addons as $key => $addon ) {

                switch ( $addon['slug'] ) {
                    case 'mailpoet':
                        if(array_key_exists($form_id, $addon['service'])){
                            $addon['service'][$form_id];
                            $mailpoetAPI = new Auto_Mail_MailPoet_API();
                            $result = $mailpoetAPI->subscribe_to_list($email, $addon['service'][$form_id]);
                        }
                        break;
                    case 'mailchimp':
                        if(array_key_exists($form_id, $addon['service'])){
                            $addon['service'][$form_id];
                            $mailchimpAPI = new AutoMailchimpAPI( $addon['api_key'] );
                            $result = $mailchimpAPI->subscribe_to_list($email, $addon['service'][$form_id]);
                        }
                        break;
                    case 'activecampaign':
                        if(array_key_exists($form_id, $addon['service'])){
                            $addon['service'][$form_id];
                            $serviceAPI = new Auto_Mail_ActiveCampaign_API( $addon['api_url'], $addon['api_key'] );
                            $result = $serviceAPI->subscribe_to_list($email, $addon['service'][$form_id]);
                        }
                        break;
                    case 'mailerlite':
                        if(array_key_exists($form_id, $addon['service'])){
                            $addon['service'][$form_id];
                            $serviceAPI = new Auto_Mail_MailerLite_API( $addon['api_key'] );
                            $result = $serviceAPI->subscribe_to_list($email, $addon['service'][$form_id]);
                        }
                        break;
                    case 'sendgrid':
                        if(array_key_exists($form_id, $addon['service'])){
                            $addon['service'][$form_id];
                            $serviceAPI = new Auto_Mail_SendGrid_API( $addon['api_key'] );
                            $submitted_data = array();
                            $submitted_data['email'] = $email;
                            $result = $serviceAPI->create_and_add_recipient_to_list($submitted_data, $addon['service'][$form_id]);
                        }
                    case 'sendinblue':
                        if(array_key_exists($form_id, $addon['service'])){
                            $addon['service'][$form_id];
                            $serviceAPI = new Auto_Mail_SendinBlue_API( $addon['api_key'] );
                            $submitted_data = array();
                            $submitted_data['email'] = $email;
                            $result = $serviceAPI->subscribe_to_list($email, $addon['service'][$form_id]);
                        }
                        break;
                    default:
                        break;
                }

            }

        }

        /**
         * Get addon data
         *
         * @since 1.0.0
         **
         * @return bool
         */
        public function get_addon_data($slug) {

            $addons = get_option( 'auto_mail_addons', false );
            $selected_addon_data = array();

            foreach ( $addons as $key => $addon ) {
                if ( $addon['slug'] == $slug ) {
                    $selected_addon_data = $addon;
                }
            }

            return $selected_addon_data;
        }

        /**
         * Get addon data
         *
         * @since 1.0.0
         **
         * @return bool
         */
        public function get_connected_list($slug, $form_id) {
            $addons = get_option( 'auto_mail_addons', false );
            $selected_addon_data = array();

            foreach ( $addons as $key => $addon ) {
                if ( $addon['slug'] == $slug ) {
                    $selected_addon_data = $addon;
                }
            }
            return $selected_addon_data['service'][$form_id];
        }

    }

endif;