<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

/**
 * Get registered addons grouped by connected status
 *
 * @since 1.0.0
 * @return array
 */
function auto_mail_get_addons() {

    // Integrations Addons
    $addons_list = Auto_Mail_Addon_Loader::get_instance()->get_addons();

    $connected_addons     = array();
    $not_connected_addons = array();

    foreach ( $addons_list as $key => $addon ) {
        if ( $addon['is_connected'] ) {
            $connected_addons[] = $addon;
        } else {
            $not_connected_addons[] = $addon;
        }
    }



    return array(
        'connected'     => $connected_addons,
        'not_connected' => $not_connected_addons,
    );
}

/**
 * Load popup template
 *
 * @since 1.0.0
 * @return string
 */
function auto_mail_load_popup($template, $dir, $form_id = 0){

    $file    = AUTO_MAIL_DIR . "/admin/views/addons/popups/".$dir."/".$template.".php";
    $content = '';
    $form_id = $form_id;

    if ( is_file( $file ) ) {
        ob_start();

        include $file;

        $content = ob_get_clean();
    }

    return $content;
}

/**
 * Save addon api data
 *
 * @since 1.0.0
 * @return string
 */
function auto_mail_save_addon_data($data){
    Auto_Mail_Addon_Loader::get_instance()->save_addon_data($data);
}

/**
 * Connect mail service
 *
 * @since 1.0.0
 * @return string
 */
function auto_mail_connect_mail_service($data){
    Auto_Mail_Addon_Loader::get_instance()->connect_mail_service($data);
}

/**
 * Get current list
 *
 * @since 1.0.0
 * @return string
 */
function auto_mail_get_connected_list($service, $form_id){
    return Auto_Mail_Addon_Loader::get_instance()->get_connected_list($service, $form_id);
}

/**
 * Get addon api data
 *
 * @since 1.0.0
 * @return string
 */
function auto_mail_get_addon_data($slug){
    $data = Auto_Mail_Addon_Loader::get_instance()->get_addon_data($slug);
    return $data;
}

/**
 * Sanitize field
 *
 * @since 1.0.0
 *
 * @param $field
 *
 * @return array|string
 */
function auto_mail_sanitize_field( $field ) {
    // If array map all fields
    if ( is_array( $field ) ) {
        return array_map( 'auto_mail_sanitize_field', $field );
    }

    return wp_strip_all_tags( $field );
}

/**
 * Sanitize field
 *
 * @since 1.0.0
 *
 * @param $field
 *
 * @return array|string
 */
function auto_mail_submit_mail_service($form_id, $email){
    Auto_Mail_Addon_Loader::get_instance()->subscribe_mail_service($form_id, $email);
}

/**
 * Check if mailpoet active
 *
 * @since 1.0.0
 * @return bool
 */
function is_mailpoet_plugin_active() {
	return class_exists( \MailPoet\API\API::class );
}