<?php
/**
 * Integration Trigger Class
 *
 * @since  1.0.0
 * @package Auto Mail
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AM_Automation_Woo_Complete_Purchase extends AM_Automation_Integration_Trigger {

    public $integration = 'woocommerce';
    public $trigger = 'woocommerce_complete_purchase';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        am_automation_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'User complete a purchase', Auto_Mail::DOMAIN ),
            'select_option'     => __( 'User complete a purchase', Auto_Mail::DOMAIN ),
            'edit_label'        => __( 'User complete a purchase', Auto_Mail::DOMAIN ),
            'log_label'         => __( 'User complete a purchase', Auto_Mail::DOMAIN ),
            'action'            => 'woocommerce_order_status_completed',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 1,
            'options'           => array(
                // No options
            ),
            'tags' => array(
                // No tags
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param int $order_id The order ID
     */
    public function listener( $order_id ) {

        error_log( 'Automations log listener for woo user complete purchase' );

        $order = wc_get_order( $order_id );

        // Bail if not a valid order
        if( ! $order ) {
            return;
        }

        // Bail if order is not marked as completed
        if ( $order->get_status() !== 'completed' ) {
            return;
        }

        // $debug = var_export($order_id, true);
        // error_log( $debug );

        $order_total = $order->get_total();

        if($order->get_user_id()){
            $user_id = $order->get_user_id();
        }else{
            $user_id = 1;
        }

        $user_email = $order->get_billing_email();

        // Trigger the complete purchase
        am_automation_trigger_event( array(
            'trigger'       => $this->trigger,
            'user_id'       => $user_id,
            'user_email'    => $user_email,
            'order_id'      => $order_id,
            'order_total'   => $order_total
        ) );

    }
}

new AM_Automation_Woo_Complete_Purchase();