<?php

class AutoMailchimpAPI {

	private $domain  = 'api.mailchimp.com';
	private $version = '3.0';

	public function __construct( $apikey = null ) {

		if ( ! is_null( $apikey ) ) {
			$this->set_apikey( $apikey );
		}

	}

	public function set_apikey( $apikey ) {
		$this->apikey = $apikey;
		$this->dc     = preg_replace( '/^([a-f0-9]+)-([a-z0-9]+)$/', '$2', $apikey );
		$this->url    = trailingslashit( 'https://' . $this->dc . '.' . $this->domain . '/' . $this->version );
	}

	public function ping() {
		return $this->get( 'ping' );
	}

	public function lists( $args = array() ) {
		$result = $this->get( 'lists', $args );
		return isset( $result->lists ) ? $result->lists : array();
	}

	public function list( $list_id, $args = array() ) {
		return $this->get( 'lists/' . $list_id, $args );
	}

	public function members( $list_id, $args = array() ) {
		return $this->get( 'lists/' . $list_id . '/members', $args );
	}

	private function get( $action, $args = array(), $timeout = 15 ) {
		return $this->do_call( 'GET', $action, $args, $timeout );
	}
	private function post( $action, $args = array(), $timeout = 15 ) {
		return $this->do_call( 'POST', $action, $args, $timeout );
	}


	private function do_call( $method, $action, $args = array(), $timeout = 15 ) {

		$url = $this->url . $action;

		$headers = array(
			'Authorization' => 'apikey ' . $this->apikey,
		);

		$body = null;

		if ( 'GET' == $method ) {
			$url = add_query_arg( $args, $url );
		} elseif ( 'POST' == $method ) {
			$body = $args;
		} else {
			return new WP_Error( 'method_not_allowed', 'This method is not allowed' );
		}

		$key = md5(
			serialize(
				array(
					$url,
					$body,
					$method,
				)
			)
		);

		if ( false !== ( $body = get_transient( 'auto_mail_mailchimp_api_request_' . $key ) ) ) {
			return $body;
		}

		$response = wp_remote_request(
			$url,
			array(
				'method'  => $method,
				'headers' => $headers,
				'timeout' => $timeout,
				'body'    => $body,
			)
		);

		if ( is_wp_error( $response ) ) {
			return $response;
		}

		$code = wp_remote_retrieve_response_code( $response );
		$body = json_decode( wp_remote_retrieve_body( $response ) );

		if ( 200 != $code ) {

			$return = new WP_Error( $body->status, $body->title . ': ' . $body->detail, $body );

			return $return;

		}

		set_transient( 'auto_mail_mailchimp_api_request_' . $key, $body, 120 );
		return $body;

	}



	/**
     * subscribe user email into list
     *
     * @return array
    */
    public function subscribe($email, $list_id){

		$params = array(
            'email_address' => $email,
            'status' => 'subscribed'
        );

		// make post request
		$return_data = $this->post('lists/'.$list_id.'/members', $params);

		$result = json_decode($return_data, true);

        return $result;
    }

	/**
         * subscribe user email into list
         *
         * @return array
         */
        public function subscribe_to_list($email, $list_id){
            $auth = base64_encode( 'user:'.$this->apikey  );
            $server_prefix = substr($this->apikey , strpos($this->apikey ,'-')+1);

            $url = 'https://'.$server_prefix.'.api.mailchimp.com/3.0/lists/'.$list_id.'/members';

            // mailchimp api need http basic authentication
            $header = array(
                'Authorization' => 'Basic ' . $auth,
                'content-type'  => 'application/json'
            );

            $params = array(
                'email_address' => $email,
                'status' => 'subscribed'
            );

            $body = json_encode($params);

            // make put request
            $return_data  = $this->make_post_request( $url, $header, $body );

            $result = json_decode($return_data, true);

			return $result;
        }

	/**
         * Make HTTP POST Resuest
         *
         * @param  string $url
         * @return string
         */
        public function make_post_request( $url, $headers = array(), $body) {
            // build http post request args
            $args = array(
                'headers' => $headers,
                'body'    => $body,
                'method'  => 'POST',
                'timeout' => 45,
            );

            $request = wp_remote_post( $url, $args );

            // retrieve the body from the raw response
            $result = wp_remote_retrieve_body( $request );

            // log error messages
            if ( is_wp_error( $request ) ) {
                return false;
            }

            if ( $request['response']['code'] != 200 ) {
                return false;
            }

            return $result;

        }

}
